package Impedance::Device;
#$Id: Device.pm,v 1.22 2015/10/21 05:58:22 sofc Exp $
##################################################################
#
#
#  Package Impedance::Device;
#
# This module defines two functions, the first is list_device_types()
# which returns a list of valid impedance element type names.
#
# The second function is a factory function: new_device($$).
# It accepts two arguments, the first is an element type name 
# (one of the types returned by list_device_types()) and
# the second argument is the element id (integer).
# The new_device($$) function returns the impedance instance created. 
#
##################################################################
use strict;
use warnings;
use Math::Complex;
use Impedance::Base;
use Impedance::RQ;
use Impedance::W;
use Impedance::H;
use Impedance::Complex;

BEGIN {
    use Exporter ();
    our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
    $VERSION = 1.0;
    %EXPORT_TAGS = (
        'standard'=>[],
                    );
    Exporter::export_ok_tags('standard');
    Exporter::export_tags('standard');
    @ISA = qw(Exporter);
}


sub list_device_types()
{
    return ('R','C','L','Q','W','H','RC','RQ','RL','O','Od','G','Gd','dL','T','Td','Par','Ser');
}

sub new_device($$)
{
    my $id = undef;
    my $type = uc(shift);
    my $nr = shift;
    die 'Not enough arguments for Impedance::new_device(), usage: new_device($type,$element_number)!' unless ($type && $nr);
    $id = Impedance::R->new($nr) if ($type eq 'R');
    $id = Impedance::L->new($nr) if ($type eq 'L');
    $id = Impedance::C->new($nr) if ($type eq 'C');
    $id = Impedance::Q->new($nr) if ($type eq 'Q');
    $id = Impedance::W->new($nr) if ($type eq 'W');
    $id = Impedance::H->new($nr) if ($type eq 'H');
    $id = Impedance::G->new($nr) if ($type eq 'G');
    $id = Impedance::Gd->new($nr) if ($type eq 'GD');
    $id = Impedance::dL->new($nr) if ($type eq 'DL');
    $id = Impedance::O->new($nr) if ($type eq 'O');
    $id = Impedance::Od->new($nr) if ($type eq 'OD');
    $id = Impedance::T->new($nr) if ($type eq 'T');
    $id = Impedance::Td->new($nr) if ($type eq 'TD');
    $id = Impedance::RC->new($nr) if ($type eq 'RC');
    $id = Impedance::RL->new($nr) if ($type eq 'RL');
    $id = Impedance::RQ->new($nr) if ($type eq 'RQ');
    $id = Impedance::Par->new($nr) if ($type eq 'PAR');
    $id = Impedance::Ser->new($nr) if ($type eq 'SER');
    return $id;
}

return 1;
